Description Dictionary Super classes Methods See Also Examples
Classification extratree learner.
Calls extraTrees::extraTrees() from package extraTree.
This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():
1 2 | mlr_learners$get("classif.extratrees")
lrn("classif.extratrees")
|
mlr3::Learner -> mlr3::LearnerClassif -> LearnerClassifExtraTrees
new()Creates a new instance of this R6 class.
LearnerClassifExtraTrees$new()
clone()The objects of this class are cloneable with this method.
LearnerClassifExtraTrees$clone(deep = FALSE)
deepWhether to make a deep clone.
Dictionary of Learners: mlr3::mlr_learners
1 2 3 4 5 6 7 | if (requireNamespace("extraTrees")) {
learner = mlr3::lrn("classif.extratrees")
print(learner)
# available parameters:
learner$param_set$ids()
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.